@@ -11,8 +11,8 @@
     ang<-runif(n-2,-pi,pi)
     v=dt*(l0*(runif(n-1)^(1/(1-mu))))
     ang=cumsum(c(runif(1,0,2*pi),ang))
-    si=c(x0[2], cumsum(v*sin(ang)))
-    co=c(x0[1], cumsum(v*cos(ang)))
+    si=c(x0[2], x0[2]+cumsum(v*sin(ang)))
+    co=c(x0[1], x0[1]+cumsum(v*cos(ang)))
     res <- as.ltraj(data.frame(co,si),date, id, burst, typeII=typeII)
     return(res)
 }
